@@ -22,11 +22,9 @@ class AbstractData:
     def __init__(self, file_name):
         self.load(file_name)
 
-
     def load(self, file_name):
         print self.__name__ + ' load method stub'
 
-
     def dump(self, file_name):
         # TODO: all data to one variable
         # data = None
@@ -50,7 +48,7 @@ class TimeRow(AbstractData):
     # X_q = None
     # centered_values = None
 
-    def load(file_name=None, row=None, time=None):
+    def load(self, file_name=None, row=None, time=None):
         if file_name is not None:
             self.load_file(file_name)
         elif row is not None and time is not None:
@@ -64,7 +62,7 @@ class TimeRow(AbstractData):
         self.values = self.raw_data[:, 4]
         self.n = len(self.time_var)
 
-    def load_arrays(row, time):
+    def load_arrays(self, row, time):
         if len(row) != len(time):
             raise ValueError('row and time must have the same length')
         self.raw_data = row
@@ -72,16 +70,16 @@ class TimeRow(AbstractData):
         self.values = row
         self.n = len(self.time_var)
 
-
     def __str__(self):
         res = str()
         if self.errors is not None:
-            get_line = lambda i: str(self.time_var[i]) + ' ' + str(self.values[i]) + ' ' + str(self.errors[i]) + '\n'
+            get_line = lambda i: str(self.time_var[i]) + ' ' + str(
+                self.values[i]) + ' ' + str(self.errors[i]) + '\n'
         else:
-            get_line = lambda i: str(self.time_var[i]) + ' ' + str(self.values[i]) + '\n'
+            get_line = lambda i: str(
+                self.time_var[i]) + ' ' + str(self.values[i]) + '\n'
 
         for i in xrange(self.n):
             res += get_line(i)
 
         return res
-
